@@ -9,6 +9,7 @@ import click
 import six
 import tabulate
 from pkg_resources import get_distribution
+from pbr import packaging
 
 from skipper import git
 from skipper import runner
@@ -30,7 +31,6 @@ def cli(ctx, registry, build_container_image, build_container_tag, build_contain
     """
     logging_level = logging.DEBUG if verbose else logging.INFO
     utils.configure_logging(name='skipper', level=logging_level)
-
     ctx.obj['registry'] = registry
     ctx.obj['build_container_image'] = build_container_image
     ctx.obj['build_container_net'] = build_container_net
@@ -42,6 +42,7 @@ def cli(ctx, registry, build_container_image, build_container_tag, build_contain
     ctx.obj['workdir'] = ctx.default_map.get('workdir')
     ctx.obj['workspace'] = ctx.default_map.get('workspace', None)
     ctx.obj['container_context'] = ctx.default_map.get('container_context')
+    utils.set_remote_registry_login_info(registry, ctx.obj)
 
 
 @cli.command()
@@ -82,7 +83,8 @@ def build(ctx, images_to_build, container_context, cache):
             build_context = ctx.obj['container_context']
         else:
             build_context = os.path.dirname(dockerfile)
-        command = ['build', '--network=host', '-f', dockerfile, '-t', fqdn_image, build_context]
+        command = ['build', '--network=host', '--build-arg', 'TAG={}'.format(tag),
+                   '-f', dockerfile, '-t', fqdn_image, build_context]
         if cache:
             cache_image = utils.generate_fqdn_image(ctx.obj['registry'], namespace=None, image=image, tag=DOCKER_TAG_FOR_CACHE)
             runner.run(['pull', cache_image])
@@ -104,18 +106,24 @@ def build(ctx, images_to_build, container_context, cache):
 @cli.command()
 @click.option('--namespace', help='Namespace to push into')
 @click.option('--force', help="Push image even if it's already in the registry", is_flag=True, default=False)
+@click.option('--pbr', help="Use PBR to tag the image", is_flag=True, default=False)
 @click.argument('image')
 @click.pass_context
-def push(ctx, namespace, force, image):
+def push(ctx, namespace, force, pbr, image):
     """
     Push a container
     """
     utils.logger.debug("Executing push command")
     _validate_global_params(ctx, 'registry')
     tag = git.get_hash()
+    tag_to_push = tag
+    if pbr:
+        # Format = pbr_version.short_hash
+        # pylint: disable=protected-access
+        tag_to_push = "{}.{}".format(packaging._get_version_from_git().replace('dev', ''), tag[:8])
     image_name = image + ':' + tag
 
-    ret = _push(ctx, force, image, image_name, namespace, tag)
+    ret = _push(ctx, force, image, image_name, namespace, tag_to_push)
     if ret != 0:
         return ret
     return ret
@@ -130,7 +138,8 @@ def _push(ctx, force, image, image_name, namespace, tag):
         utils.logger.error('Failed to tag image: %(tag)s as fqdn', dict(tag=image_name, fqdn=fqdn_image))
         sys.exit(ret)
     repo_name = utils.generate_fqdn_image(None, namespace, image, tag=None)
-    images_info = utils.get_remote_images_info([repo_name], ctx.obj['registry'])
+    images_info = utils.get_remote_images_info([repo_name], ctx.obj['registry'],
+                                               ctx.obj.get('username'), ctx.obj.get('password'))
     tags = [info[-1] for info in images_info]
     if tag in tags:
         if not force:
@@ -166,7 +175,8 @@ def images(ctx, remote):
     if remote:
         _validate_global_params(ctx, 'registry')
         try:
-            images_info += utils.get_remote_images_info(images_names, ctx.obj['registry'])
+            images_info += utils.get_remote_images_info(images_names, ctx.obj['registry'],
+                                                        ctx.obj.get('username'), ctx.obj.get('password'))
         except Exception as exp:
             raise click.exceptions.ClickException('Got unknow error from remote registry %(error)s' % dict(error=exp.message))
 
@@ -186,7 +196,8 @@ def rmi(ctx, remote, image, tag):
     _validate_project_image(image)
     if remote:
         _validate_global_params(ctx, 'registry')
-        utils.delete_image_from_registry(ctx.obj['registry'], image, tag)
+        utils.delete_image_from_registry(ctx.obj['registry'], image, tag,
+                                         ctx.obj.get('username'), ctx.obj.get('password'))
     else:
         utils.delete_local_image(image, tag)
 
@@ -209,6 +220,8 @@ def run(ctx, interactive, name, env, cache, command):
                                                ctx.obj['build_container_tag'],
                                                ctx.obj['git_revision'],
                                                ctx.obj['container_context'],
+                                               ctx.obj.get('username'),
+                                               ctx.obj.get('password'),
                                                cache)
     return runner.run(list(command),
                       fqdn_image=build_container,
@@ -241,6 +254,8 @@ def make(ctx, interactive, name, env, makefile, cache, make_params):
                                                ctx.obj['build_container_tag'],
                                                ctx.obj['git_revision'],
                                                ctx.obj['container_context'],
+                                               ctx.obj.get('username'),
+                                               ctx.obj.get('password'),
                                                cache)
     command = ['make', '-f', makefile] + list(make_params)
     return runner.run(command,
@@ -271,6 +286,8 @@ def shell(ctx, env, name, cache):
                                                ctx.obj['build_container_tag'],
                                                ctx.obj['git_revision'],
                                                ctx.obj['container_context'],
+                                               ctx.obj.get('username'),
+                                               ctx.obj.get('password'),
                                                cache)
     return runner.run(['bash'],
                       fqdn_image=build_container,
@@ -313,7 +330,7 @@ def _push_to_registry(registry, fqdn_image):
         sys.exit(ret)
 
 
-def _prepare_build_container(registry, image, tag, git_revision, container_context, use_cache):
+def _prepare_build_container(registry, image, tag, git_revision, container_context, username, password, use_cache):
 
     if tag is not None:
 
@@ -323,7 +340,7 @@ def _prepare_build_container(registry, image, tag, git_revision, container_conte
             utils.logger.info("Using build container: %(image_name)s", dict(image_name=tagged_image_name))
             return tagged_image_name
 
-        if utils.remote_image_exist(registry, image, tag):
+        if utils.remote_image_exist(registry, image, tag, username, password):
             fqdn_image = utils.generate_fqdn_image(registry, None, image, tag)
             utils.logger.info("Using build container: %(fqdn_image)s", dict(fqdn_image=fqdn_image))
             return fqdn_image
