@@ -1,16 +1,24 @@
 #!/usr/bin/env bash
 
 if ! [ -z "${SKIPPER_DOCKER_GID}" ];then
+
+  if [ ${SKIPPER_USERNAME} == root ]; then
+      HOME_DIR=/root
+  else
+      HOME_DIR=/home/${SKIPPER_USERNAME}
+  fi
+
   SKIP_HOME_DIR_PARAM=""
+
   # if home directory already exists, useradd should not try to create it
-  [ -d /home/${SKIPPER_USERNAME} ] && SKIP_HOME_DIR_PARAM="--no-create-home"
+  [ -d ${HOME_DIR} ] && SKIP_HOME_DIR_PARAM="--no-create-home"
 
   getent passwd ${SKIPPER_USERNAME} > /dev/null
   if [ x"$?" != x"0" ]; then
     useradd -u ${SKIPPER_UID} --non-unique ${SKIP_HOME_DIR_PARAM} "${SKIPPER_USERNAME}"
   fi
 
-  chown ${SKIPPER_USERNAME}:${SKIPPER_USERNAME} /home/${SKIPPER_USERNAME}
+  chown ${SKIPPER_USERNAME}:${SKIPPER_USERNAME} ${HOME_DIR}
 
   if [ $(getent group docker) ]; then
     groupmod -o -g ${SKIPPER_DOCKER_GID} docker
