@@ -39,6 +39,7 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, volume
     cmd = ['run']
     if interactive:
         cmd += ['-i']
+        cmd += ['-e', 'SKIPPER_INTERACTIVE=True']
     if name:
         cmd += ['--name', name]
 
@@ -64,8 +65,11 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, volume
     cmd += ['-e', 'HOME=%(homedir)s' % dict(homedir=homedir)]
 
     if utils.get_runtime_command() == "docker":
-        docker_gid = grp.getgrnam('docker').gr_gid
-        cmd += ['-e', 'SKIPPER_DOCKER_GID=%(docker_gid)s' % dict(docker_gid=docker_gid)]
+        try:
+            docker_gid = grp.getgrnam('docker').gr_gid
+            cmd += ['-e', 'SKIPPER_DOCKER_GID=%(docker_gid)s' % dict(docker_gid=docker_gid)]
+        except KeyError:
+            pass
 
     if use_cache:
         cmd += ['-e', 'SKIPPER_USE_CACHE_IMAGE=True']
@@ -90,7 +94,12 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, volume
 def handle_volumes_bind_mount(docker_cmd, homedir, volumes, workspace):
     volumes = volumes or []
     volumes.extend(['%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=homedir),
-                    '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=homedir)])
+                    '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=homedir),
+                    '%(homedir)s/.docker/config.json:%(homedir)s/.docker/config.json:ro' % dict(homedir=homedir)])
+
+    # required for docker login (certificates)
+    if os.path.exists('/etc/docker'):
+        volumes.append('/etc/docker:/etc/docker:ro')
 
     if utils.get_runtime_command() == utils.PODMAN:
         volumes.extend([
@@ -103,11 +112,13 @@ def handle_volumes_bind_mount(docker_cmd, homedir, volumes, workspace):
             volumes.append('/var/lib/osmosis:/var/lib/osmosis:rw')
     else:
         volumes.extend([
-            '%(workspace)s:%(workspace)s:rw,Z' % dict(workspace=workspace),
-            '/var/lib/osmosis:/var/lib/osmosis:rw,Z',
-            '/var/run/docker.sock:/var/run/docker.sock:Z',
-            '%s:/opt/skipper/skipper-entrypoint.sh:Z' % utils.get_extra_file("skipper-entrypoint.sh"),
+            '%(workspace)s:%(workspace)s:rw' % dict(workspace=workspace),
+            '/var/run/docker.sock:/var/run/docker.sock:rw',
+            '%s:/opt/skipper/skipper-entrypoint.sh' % utils.get_extra_file("skipper-entrypoint.sh"),
             ])
+        # Will fail on Mac
+        if os.path.exists('/var/lib/osmosis'):
+            volumes.append('/var/lib/osmosis:/var/lib/osmosis:rw')
 
     for volume in volumes:
         if ":" not in volume:
@@ -136,9 +147,9 @@ def create_vol_localpath_if_needed(volume):
     # that's why we create it as file
     # 2. .docker/config.json - if it is required and doesn't exists we want to create is as file with {} as data
     if ".gitconfig" in host_path and not os.path.exists(host_path):
-        utils.create_path_and_add_data(host_path, data="", is_file=True)
+        utils.create_path_and_add_data(full_path=host_path, data="", is_file=True)
     elif "docker/config.json" in host_path and not os.path.exists(host_path):
-        utils.create_path_and_add_data(host_path, data="{}", is_file=True)
+        utils.create_path_and_add_data(full_path=host_path, data="{}", is_file=True)
     elif not os.path.exists(host_path):
         # If the local directory of a mount entry doesn't exist, docker will by
         # default create a directory in that path. Docker runs in systemd context,
